<?xml version="1.0" encoding="UTF-8"?>
 <xsl:stylesheet version="1.0"
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
     xmlns:ap="http://schemas.mindjet.com/MindManager/Application/2003"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xmlns:cor="http://schemas.mindjet.com/MindManager/Core/2003">
  <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
   <xsl:template match="/">
     <xsl:element name="BrainData">
     	<xsl:element name="Thoughts">
     			<xsl:apply-templates select="ap:Map/ap:MarkersSetGroup/ap:TaskResourceMarkers"/>
       	  <xsl:apply-templates select="ap:Map/ap:OneTopic/ap:Topic"/>
       	  <xsl:element name="FloatingTopics">
       	  	<xsl:apply-templates select="ap:Map/ap:OneTopic/ap:Topic/ap:FloatingTopics/ap:Topic"/>
       		</xsl:element>
     </xsl:element> 
     <xsl:element name="Relationships">
     	<xsl:apply-templates select="ap:Map/ap:Relationships/ap:Relationship"/>
     </xsl:element>
   </xsl:element>
   </xsl:template>
   <xsl:template match="ap:TaskResourceMarkers">
   	 <xsl:for-each select="ap:TaskResourceMarker">
   	 	 <xsl:element name="ThoughtType">
   	 	 	 <xsl:element name="name">
   	 	 	 	 <xsl:value-of select="ap:Name/@Name"/>
   	 	 	 </xsl:element>
   	 	 	 <xsl:element name="guid">
   	 	 	 	 <xsl:value-of select="@OId"/>
   	 	 	 </xsl:element>
   	 	 </xsl:element>
   	 </xsl:for-each>
   </xsl:template>
   <xsl:template match="ap:Relationship">
   	 <xsl:element name="relationship">
   	 	 <xsl:for-each select="ap:ConnectionGroup">
   	 	 	 <xsl:choose>
   	 	 	 	 <xsl:when test="@Index = '0'">
   	 	 	 	 	 <xsl:element name="guidA">
   	 	 	 	 	 	 <xsl:value-of select="ap:Connection/ap:ObjectReference/@OIdRef"/>
   	 	 	 	 	 </xsl:element>
   	 	 	 	 </xsl:when>
   	 	 	 	 <xsl:when test="@Index = '1'">
   	 	 	 	 	 <xsl:element name="guidB">
   	 	 	 	 	 	 <xsl:value-of select="ap:Connection/ap:ObjectReference/@OIdRef"/>
   	 	 	 	 	 </xsl:element>
   	 	 	 	 </xsl:when>
   	 	 	 	 <xsl:otherwise>
   	 	 	 	 	 <xsl:element name="ThisShouldNeverHappen">
   	 	 	 	 	 	 <xsl:value-of select="@Index"/>
   	 	 	 	 	 </xsl:element>
   	 	 	 	 </xsl:otherwise>
   	 	 	 </xsl:choose>
   	 	 </xsl:for-each>
   	 	<xsl:if test="ap:Color/@LineColor">
   	 		<xsl:element name="linkColor">
   	 			<xsl:value-of select="ap:Color/@LineColor"/>
   	 		</xsl:element>
   	 	</xsl:if>
   	 </xsl:element>
   </xsl:template>
   <xsl:template match="ap:Topic | ap:TaskResourceMarker">
     <xsl:element name="Thought">
       <xsl:element name="name">
       	 <xsl:choose>
       	 		<xsl:when test="normalize-space(ap:Text/@PlainText) = ''">
       	 			<!-- If here topic still has default name. TODO: Get the default name (Central Topic, Main Topic, Sub Topic, etc...) -->
       	 			<xsl:value-of select="'Unnamed Topic'"/>
       	 		</xsl:when>
       	 		<xsl:otherwise>
      	 			<xsl:value-of select="ap:Text/@PlainText"/>
       	 		</xsl:otherwise>
       	 </xsl:choose>
       </xsl:element>
       <xsl:if test="ap:OneImage/ap:Image/ap:ImageData/@ImageType = 'urn:mindjet:PngImage'">
       	<xsl:element name="thoughtImage">
       		<xsl:if test="ap:OneImage/ap:Image/ap:ImageData/cor:Base64">
       			<xsl:value-of select="ap:OneImage/ap:Image/ap:ImageData/cor:Base64"/>
       		</xsl:if>
       		<xsl:if test="ap:OneImage/ap:Image/ap:ImageData/@ImageType = 'urn:mindjet:PngImage'">
       			<xsl:value-of select="ap:OneImage/ap:Image/ap:ImageData/cor:Uri"/>
       		</xsl:if>
       	</xsl:element>
       </xsl:if>
       <xsl:if test="ap:OneImage/ap:Image/ap:ImageData/@ImageType = 'urn:mindjet:MetafileImage'">
       	<xsl:element name="thoughtImage">
       		<xsl:value-of select="ap:OneImage/ap:Image/ap:AlternateImageData/ap:AlternateImages/cor:Uri"/>
       	</xsl:element>
       </xsl:if>
       <xsl:for-each select="ap:IconsGroup/ap:Icons/ap:Icon">
       	 <xsl:if test="@xsi:type = 'ap:StockIcon'">
       	 	 <xsl:element name="icon">
       	 	 	 <xsl:value-of select="@IconType"/>
       	 	 </xsl:element>
       	 </xsl:if>
       </xsl:for-each>
       <xsl:if test="ap:Text/ap:Font/@Color">
       	<xsl:element name="thoughtTextColor">
       		<xsl:value-of select="ap:Text/ap:Font/@Color"/>
       	</xsl:element>
       </xsl:if>
       <xsl:if test="ap:Hyperlink/@Url">
       	<xsl:element name="thoughtUrl">
       		<xsl:value-of select="ap:Hyperlink/@Url"/>
       	</xsl:element>
       </xsl:if>
       <xsl:for-each select="ap:Task">
       	<xsl:element name="reminder">
       		<xsl:if test="@StartDate">
       	  	<xsl:element name="reminderStartDate">
       	  		<xsl:value-of select="@StartDate"/>
       	  	</xsl:element>
       	  </xsl:if>
       	  <xsl:if test="@DeadlineDate">
       	  	<xsl:element name="reminderEndDate">
       	  	  <xsl:value-of select="@DeadlineDate"/>
       	  	</xsl:element>
       	  </xsl:if>
       	  <xsl:element name="reminderName">
       	  	<xsl:value-of select="@Resources"/>
       	  </xsl:element>
       	  <xsl:if test="@TaskPercentage">
       	  	<xsl:element name="reminderPercentComplete">
       	  	  <xsl:value-of select="@TaskPercentage"/>
       	  	</xsl:element>
       	  </xsl:if>
        </xsl:element>
        <xsl:if test="@TaskPriority">
        	<xsl:element name="taskPriority">
       	  	<xsl:value-of select="@TaskPriority"/>
       	  </xsl:element>
       	</xsl:if>
       	<xsl:if test="@Resources">
       		<xsl:element name="thoughtTypeName">
       	  	<xsl:value-of select="@Resources"/>
       	  </xsl:element>
       	</xsl:if>
       </xsl:for-each> 	
       <xsl:element name="notes">
         <xsl:value-of select="ap:NotesGroup/ap:NotesXhtmlData"/>
       </xsl:element>
       <xsl:for-each select="ap:NotesGroup/ap:NotesData">
       	<xsl:element name="notesImageName">
       		<xsl:value-of select="@ImageUri"/>
       	</xsl:element>
       	<xsl:element name="notesImageLocation">
       		<xsl:value-of select="cor:Uri"/>
       	</xsl:element>
       </xsl:for-each>      
       	 <xsl:for-each select="ap:AttachmentGroup/ap:AttachmentData">
       	 	<xsl:variable name="fileName" select="@FileName"/>
       	 	<xsl:element name="attachment">
       	 		<!-- This first element is for MM8, the others below are for MM7 -->
       	 		<xsl:element name="attachmentUri">
       	 			<xsl:value-of select="cor:Uri"/>
       	 		</xsl:element>
       	 		<xsl:element name="attachmentName">
       	 			<xsl:value-of select="$fileName"/>
       	 		</xsl:element>
       	 		<xsl:element name="fileCreated">
       	 			<xsl:value-of select="@FileCreated"/>
       	 		</xsl:element>
       	 		<xsl:element name="fileModified">
       	 			<xsl:value-of select="@FileModified"/>
       	 		</xsl:element>
       	 		<xsl:element name="attachmentData">
       	 			<xsl:value-of select="cor:Base64"/>
       	 		</xsl:element>
       	 	</xsl:element>
       	 </xsl:for-each>
       	<xsl:if test="ap:Color/@FillColor">
       		<xsl:element name="thoughtColor">
       			<xsl:value-of select="ap:Color/@FillColor"/>
       		</xsl:element>
       	</xsl:if>
       	<xsl:if test="ap:Color/@LineColor">
       		<xsl:element name="thoughtLinksColor">
       			<xsl:value-of select="ap:Color/@LineColor"/>
       		</xsl:element>
       	</xsl:if>
       <xsl:variable name="OId" select="@OId"/>
       <xsl:element name="guid">
       	<xsl:value-of select="$OId"/>
       </xsl:element>
       <xsl:if test="ap:SubTopics">
       	<xsl:apply-templates select="ap:SubTopics"/>
       </xsl:if>
     </xsl:element>
   </xsl:template>
 </xsl:stylesheet>
